@@ -14,6 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_codeguru_reviewer.paginator import ListRepositoryAssociationsPaginator
@@ -52,45 +53,46 @@ class Exceptions:
 
 class CodeGuruReviewerClient:
     """
-    [CodeGuruReviewer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
+    [CodeGuruReviewer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def associate_repository(
         self, Repository: RepositoryTypeDef, ClientRequestToken: str = None
     ) -> AssociateRepositoryResponseTypeDef:
         """
-        [Client.associate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
+        [Client.associate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
         """
 
     def describe_code_review(self, CodeReviewArn: str) -> DescribeCodeReviewResponseTypeDef:
         """
-        [Client.describe_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
+        [Client.describe_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
         """
 
     def describe_recommendation_feedback(
         self, CodeReviewArn: str, RecommendationId: str, UserId: str = None
     ) -> DescribeRecommendationFeedbackResponseTypeDef:
         """
-        [Client.describe_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
+        [Client.describe_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
         """
 
     def describe_repository_association(
         self, AssociationArn: str
     ) -> DescribeRepositoryAssociationResponseTypeDef:
         """
-        [Client.describe_repository_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
+        [Client.describe_repository_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
         """
 
     def disassociate_repository(self, AssociationArn: str) -> DisassociateRepositoryResponseTypeDef:
         """
-        [Client.disassociate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
+        [Client.disassociate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
         """
 
     def generate_presigned_url(
@@ -101,7 +103,7 @@ class CodeGuruReviewerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
         """
 
     def list_code_reviews(
@@ -116,7 +118,7 @@ class CodeGuruReviewerClient:
         NextToken: str = None,
     ) -> ListCodeReviewsResponseTypeDef:
         """
-        [Client.list_code_reviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
+        [Client.list_code_reviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
         """
 
     def list_recommendation_feedback(
@@ -128,14 +130,14 @@ class CodeGuruReviewerClient:
         RecommendationIds: List[str] = None,
     ) -> ListRecommendationFeedbackResponseTypeDef:
         """
-        [Client.list_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
+        [Client.list_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
         """
 
     def list_recommendations(
         self, CodeReviewArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListRecommendationsResponseTypeDef:
         """
-        [Client.list_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
+        [Client.list_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
         """
 
     def list_repository_associations(
@@ -150,7 +152,7 @@ class CodeGuruReviewerClient:
         NextToken: str = None,
     ) -> ListRepositoryAssociationsResponseTypeDef:
         """
-        [Client.list_repository_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
+        [Client.list_repository_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
         """
 
     def put_recommendation_feedback(
@@ -160,12 +162,12 @@ class CodeGuruReviewerClient:
         Reactions: List[Literal["ThumbsUp", "ThumbsDown"]],
     ) -> Dict[str, Any]:
         """
-        [Client.put_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
+        [Client.put_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
         """
 
     def get_paginator(
         self, operation_name: Literal["list_repository_associations"]
     ) -> ListRepositoryAssociationsPaginator:
         """
-        [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
+        [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
         """
